@@ -4,8 +4,10 @@
 #'
 #' @param clusters A vector of length N that indicates which cluster each unit belongs to.
 #' @param m Use for a two-arm design in which m clusters are assigned to treatment and N-m clusters are assigned to control. (optional)
+#' @param m_unit Use for a two-arm design in which exactly unique(m_unit) clusters are assigned to treatment and the remainder are assigned to control. m_unit must be of length N and must be the same for all units (optional)
 #' @param m_each Use for a multi-arm design in which the values of m_each determine the number of clusters assigned to each condition. m_each must be a numeric vector in which each entry is a nonnegative integer that describes how many clusters should be assigned to the 1st, 2nd, 3rd... treatment condition. m_each must sum to N. (optional)
 #' @param prob Use for a two-arm design in which either floor(N_clusters*prob) or ceiling(N_clusters*prob) clusters are assigned to treatment. The probability of assignment to treatment is exactly prob because with probability 1-prob, floor(N_clusters*prob) clusters will be assigned to treatment and with probability prob, ceiling(N_clusters*prob) clusters will be assigned to treatment. prob must be a real number between 0 and 1 inclusive. (optional)
+#' @param prob_unit Use for a two-arm design. unique(prob_unit) will be passed to the prob argument and must be the same for all units.
 #' @param prob_each Use for a multi-arm design in which the values of prob_each determine the probabilities of assignment to each treatment condition. prob_each must be a numeric vector giving the probability of assignment to each condition. All entries must be nonnegative real numbers between 0 and 1 inclusive and the total must sum to 1. Because of integer issues, the exact number of clusters assigned to each condition may differ (slightly) from assignment to assignment, but the overall probability of assignment is exactly prob_each. (optional)
 #' @param num_arms The total number of treatment arms. If unspecified, will be determined from the length of m_each or conditions.
 #' @param conditions A character vector giving the names of the treatment groups. If unspecified, the treatment groups will be named T1, T2, T3, etc.
@@ -44,8 +46,10 @@
 #' table(Z, clusters)
 cluster_ra <- function(clusters = NULL,
                        m = NULL,
+                       m_unit = NULL,
                        m_each = NULL,
                        prob = NULL,
+                       prob_unit = NULL,
                        prob_each = NULL,
                        num_arms = NULL,
                        conditions = NULL,
@@ -57,9 +61,14 @@ cluster_ra <- function(clusters = NULL,
   n_per_clust <- tapply(clusters, clusters, length)
   n_clust <- length(n_per_clust)
   
+  if(!is.null(m_unit)) {
+    m_unit <- rep(unique(m_unit), n_clust)
+  }
+  
   delegate_args <- list(
     N = n_clust,
     prob = prob,
+    prob_unit = rep(unique(prob_unit), n_clust),
     prob_each = prob_each,
     num_arms = num_arms,
     conditions = conditions,
@@ -67,7 +76,7 @@ cluster_ra <- function(clusters = NULL,
   )
   
   z_clust <- cluster_ra_helper("simple_ra", "complete_ra",
-                               delegate_args, simple, m, m_each)
+                               delegate_args, simple, m, m_unit, m_each)
   
   assignment <- rep(z_clust, n_per_clust)
   assignment <-
@@ -119,8 +128,10 @@ cluster_ra <- function(clusters = NULL,
 cluster_ra_probabilities <-
   function(clusters = NULL,
            m = NULL,
+           m_unit = NULL,
            m_each = NULL,
            prob = NULL,
+           prob_unit = NULL,
            prob_each = NULL,
            num_arms = NULL,
            conditions = NULL,
@@ -133,9 +144,13 @@ cluster_ra_probabilities <-
     unique_clust <- names(n_per_clust)
     n_clust <- length(unique_clust)
     
+    
+    if(!is.null(m_unit)){m_unit <- rep(unique(m_unit), n_clust)}
+    
     delegate_args <- list(
       N = n_clust,
       prob = prob,
+      prob_unit = rep(unique(prob_unit), n_clust),
       prob_each = prob_each,
       num_arms = num_arms,
       conditions = conditions,
@@ -150,6 +165,7 @@ cluster_ra_probabilities <-
         delegate_args,
         simple,
         m,
+        m_unit,
         m_each
       )
     
@@ -168,12 +184,14 @@ cluster_ra_helper <-
            delegate_args,
            simple,
            m,
+           m_unit,
            m_each) {
     if (simple) {
       delegate <- simple_delegate
     } else{
       delegate <- complete_delegate
       delegate_args$m <- m
+      delegate_args$m_unit <- m_unit
       delegate_args$m_each <- m_each
     }
     
